==> nextcloud-24.0.12.tgz: nextcloud/apps/encryption/l10n/ja.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "復旧キーのパスワードがありません",
    "Please repeat the recovery key password" : "復旧キーのパスワードをもう一度入力",
    "Repeated recovery key password does not match the provided recovery key password" : "入力された復旧キーのパスワードが一致しません。",
    "Recovery key successfully enabled" : "復旧キーを正常に有効化しました",
    "Could not enable recovery key. Please check your recovery key password!" : "復旧キーを有効にできませんでした。リカバリ用のキーのパスワードを確認してください！",
    "Recovery key successfully disabled" : "復旧キーを正常に無効化しました",
    "Could not disable recovery key. Please check your recovery key password!" : "復旧キーを無効化できませんでした。リカバリ用のキーのパスワードを確認してください！",
    "Missing parameters" : "パラメータが不足しています",
    "Please provide the old recovery password" : "古い復旧キーのパスワードを入力",
    "Please provide a new recovery password" : "新しい復旧キーのパスワードを入力",
    "Please repeat the new recovery password" : "新しい復旧キーのパスワードをもう一度入力",
    "Password successfully changed." : "パスワードを変更できました。",
    "Could not change the password. Maybe the old password was not correct." : "パスワードを変更できませんでした。古いパスワードが間違っているかもしれません。",
    "Recovery Key disabled" : "復旧キーが無効になりました。",
    "Recovery Key enabled" : "復旧キーが有効になりました。",
    "Could not enable the recovery key, please try again or contact your administrator" : "復旧キーを有効化できませんでした。もう一度試してみるか、管理者に問い合わせてください。",
    "Could not update the private key password." : "秘密鍵のパスワードを更新できませんでした。",
    "The old password was not correct, please try again." : "古いパスワードが一致しませんでした。もう一度入力してください。",
    "The current log-in password was not correct, please try again." : "ログインパスワードが一致しませんでした。もう一度入力してください。",
    "Private key password successfully updated." : "秘密鍵のパスワードが正常に更新されました。",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "暗号化アプリの無効なプライベートキーです。あなたの暗号化されたファイルへアクセスするために、個人設定からプライベートキーのパスワードを更新してください。",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "暗号化アプリは有効ですが、あなたの暗号化キーは初期化されていません。ログアウトした後に、再度ログインしてください",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "暗号化モジュールを利用する場合は、管理者設定でサーバーサイド暗号化を有効にしてください。",
    "Encryption app is enabled and ready" : "暗号化アプリは有効になっており、準備が整いました",
    "Bad Signature" : "不正な署名",
    "Missing Signature" : "署名が存在しません",
    "one-time password for server-side-encryption" : "サーバーサイド暗号化のワンタイムパスワード",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "このファイルを復号化できません、共有ファイルの可能性があります。ファイルの所有者にお願いして、ファイルを共有しなおしてもらってください。",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "このファイルを読み取ることができません、共有ファイルの可能性があります。ファイルの所有者にお願いして、ファイルを共有しなおしてもらってください。",
    "Default encryption module" : "デフォルトの暗号化モジュール",
    "Default encryption module for server-side encryption" : "サーバーサイド暗号化のデフォルト暗号化モジュール",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "暗号化アプリは有効ですが、あなたの暗号化キーは初期化されていません。ログアウトした後に、再度ログインしてください",
    "Encrypt the home storage" : "メインストレージ暗号化",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "このオプションを有効にすると、外部ストレージ接続ストレージだけが暗号化されるのではなく、メインストレージのファイルすべてが暗号化されます。",
    "Enable recovery key" : "復旧キーを有効にする",
    "Disable recovery key" : "復旧キーを無効にする",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "復旧キーは、ファイルの暗号化に使う特別な暗号化キーです。ユーザーがパスワードを忘れてしまった場合には、リカバリキーを使ってユーザーのファイルを復元することができます。",
    "Recovery key password" : "復旧キーのパスワード",
    "Repeat recovery key password" : "復旧キーのパスワードをもう一度入力",
    "Change recovery key password:" : "復旧キーのパスワードを変更:",
    "Old recovery key password" : "古い復旧キーのパスワード",
    "New recovery key password" : "新しい復旧キーのパスワード",
    "Repeat new recovery key password" : "新しい復旧キーのパスワードをもう一度入力",
    "Change Password" : "パスワードを変更",
    "Basic encryption module" : "基本暗号化モジュール",
    "Your private key password no longer matches your log-in password." : "もはや秘密鍵はログインパスワードと一致しません。",
    "Set your old private key password to your current log-in password:" : "古い秘密鍵のパスワードを現在のログインパスワードに設定:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "古いパスワードを覚えていない場合、管理者に尋ねてファイルを回復することができます。",
    "Old log-in password" : "古いログインパスワード",
    "Current log-in password" : "現在のログインパスワード",
    "Update Private Key Password" : "秘密鍵のパスワードを更新",
    "Enable password recovery:" : "パスワードリカバリを有効に:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "このオプションを有効にすると、パスワードを紛失した場合も、暗号化されたファイルに再度アクセスすることができるようになります。",
    "Enabled" : "有効",
    "Disabled" : "無効",
    "In order to use this encryption module you need to enable server-side\n\t\tencryption in the admin settings. Once enabled this module will encrypt\n\t\tall your files transparently. The encryption is based on AES 256 keys.\n\t\tThe module won't touch existing files, only new files will be encrypted\n\t\tafter server-side encryption was enabled. It is also not possible to\n\t\tdisable the encryption again and switch back to a unencrypted system.\n\t\tPlease read the documentation to know all implications before you decide\n\t\tto enable server-side encryption." : "この暗号化モジュールを使うには管理者画面でサーバーサイド暗号化を有効にする\n\t\t必要があります。このモジュールを一旦有効にすると全てのファイルが\n\t\t意識することなく暗号化されます。AES 256bit の鍵で暗号化されます。\n\t\tこのモジュールは既存ファイルはそのままで、サーバーサイド暗号化を\n\t\t有効にした後の新しいファイルのみ暗号化します。 一旦暗号化したシステムを\n\t\t無効化して元の暗号化されていない状態に戻すことはできません。\n\t\tサーバーサイド暗号化するかどうか決める前にドキュメントをよく読んで\n\t\t全ての要件を確認してください。",
    "Hey there,\n\nThe administration enabled server-side-encryption. Your files were encrypted using the password \"%s\".\n\nPlease login to the web interface, go to the section \"Basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"Old log-in password\" field and your current login-password.\n\n" : "こんにちは\n\n管理者がサーバーサイド暗号化を有効にしました。\"%s\"というパスワードであなたのファイルが暗号化されました。\n\nWeb画面からログインして、個人設定画面の\"基本暗号化モジュール\"セクションにいき、暗号化パスワードの更新をお願いします。\"旧ログインパスワード\"部分に上記パスワードを入力し、現在のログインパスワードで更新します。\n",
    "The share will expire on %s." : "共有は %s で有効期限が切れます。",
    "Cheers!" : "それでは！",
    "Hey there,<br><br>The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"Basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"Old log-in password\" field and your current login-password.<br><br>" : "こんにちは、<br><br>管理者がサーバーサイド暗号化を有効にしました。<strong>%s</strong>というパスワードであなたのファイルが暗号化されました。<br><br>Web画面からログインして、個人設定画面の\"基本暗号化モジュール\"のセクションにいき、暗号化パスワードの更新をお願いします。\"旧ログインパスワード\"部分に上記パスワードを入力し、現在のログインパスワードで更新します。<br><br>"
},
"nplurals=1; plural=0;");

==> nextcloud-25.0.5.tgz: nextcloud/apps/encryption/l10n/ja.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "復旧キーのパスワードがありません",
    "Please repeat the recovery key password" : "復旧キーのパスワードをもう一度入力",
    "Repeated recovery key password does not match the provided recovery key password" : "入力された復旧キーのパスワードが一致しません。",
    "Recovery key successfully enabled" : "復旧キーを正常に有効化しました",
    "Could not enable recovery key. Please check your recovery key password!" : "復旧キーを有効にできませんでした。リカバリ用のキーのパスワードを確認してください！",
    "Recovery key successfully disabled" : "復旧キーを正常に無効化しました",
    "Could not disable recovery key. Please check your recovery key password!" : "復旧キーを無効化できませんでした。リカバリ用のキーのパスワードを確認してください！",
    "Missing parameters" : "パラメータが不足しています",
    "Please provide the old recovery password" : "古い復旧キーのパスワードを入力",
    "Please provide a new recovery password" : "新しい復旧キーのパスワードを入力",
    "Please repeat the new recovery password" : "新しい復旧キーのパスワードをもう一度入力",
    "Password successfully changed." : "パスワードを変更できました。",
    "Could not change the password. Maybe the old password was not correct." : "パスワードを変更できませんでした。古いパスワードが間違っているかもしれません。",
    "Recovery Key disabled" : "復旧キーが無効になりました。",
    "Recovery Key enabled" : "復旧キーが有効になりました。",
    "Could not enable the recovery key, please try again or contact your administrator" : "復旧キーを有効化できませんでした。もう一度試してみるか、管理者に問い合わせてください。",
    "Could not update the private key password." : "秘密鍵のパスワードを更新できませんでした。",
    "The old password was not correct, please try again." : "古いパスワードが一致しませんでした。もう一度入力してください。",
    "The current log-in password was not correct, please try again." : "ログインパスワードが一致しませんでした。もう一度入力してください。",
    "Private key password successfully updated." : "秘密鍵のパスワードが正常に更新されました。",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "暗号化アプリの無効なプライベートキーです。あなたの暗号化されたファイルへアクセスするために、個人設定からプライベートキーのパスワードを更新してください。",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "暗号化アプリは有効ですが、あなたの暗号化キーは初期化されていません。ログアウトした後に、再度ログインしてください",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "暗号化モジュールを利用する場合は、管理者設定でサーバーサイド暗号化を有効にしてください。",
    "Encryption app is enabled and ready" : "暗号化アプリは有効になっており、準備が整いました",
    "Bad Signature" : "不正な署名",
    "Missing Signature" : "署名が存在しません",
    "one-time password for server-side-encryption" : "サーバーサイド暗号化のワンタイムパスワード",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "このファイルを復号化できません、共有ファイルの可能性があります。ファイルの所有者にお願いして、ファイルを共有しなおしてもらってください。",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "このファイルを読み取ることができません、共有ファイルの可能性があります。ファイルの所有者にお願いして、ファイルを共有しなおしてもらってください。",
    "Default encryption module" : "デフォルトの暗号化モジュール",
    "Default encryption module for server-side encryption" : "サーバーサイド暗号化のデフォルト暗号化モジュール",
    "In order to use this encryption module you need to enable server-side\n\t\tencryption in the admin settings. Once enabled this module will encrypt\n\t\tall your files transparently. The encryption is based on AES 256 keys.\n\t\tThe module won't touch existing files, only new files will be encrypted\n\t\tafter server-side encryption was enabled. It is also not possible to\n\t\tdisable the encryption again and switch back to a unencrypted system.\n\t\tPlease read the documentation to know all implications before you decide\n\t\tto enable server-side encryption." : "この暗号化モジュールを使うには管理者画面でサーバーサイド暗号化を有効にする\n\t\t必要があります。このモジュールを一旦有効にすると全てのファイルが\n\t\t意識することなく暗号化されます。AES 256bit の鍵で暗号化されます。\n\t\tこのモジュールは既存ファイルはそのままで、サーバーサイド暗号化を\n\t\t有効にした後の新しいファイルのみ暗号化します。 一旦暗号化したシステムを\n\t\t無効化して元の暗号化されていない状態に戻すことはできません。\n\t\tサーバーサイド暗号化するかどうか決める前にドキュメントをよく読んで\n\t\t全ての要件を確認してください。",
    "Hey there,\n\nThe administration enabled server-side-encryption. Your files were encrypted using the password \"%s\".\n\nPlease login to the web interface, go to the section \"Basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"Old log-in password\" field and your current login-password.\n\n" : "こんにちは\n\n管理者がサーバーサイド暗号化を有効にしました。\"%s\"というパスワードであなたのファイルが暗号化されました。\n\nWeb画面からログインして、個人設定画面の\"基本暗号化モジュール\"セクションにいき、暗号化パスワードの更新をお願いします。\"旧ログインパスワード\"部分に上記パスワードを入力し、現在のログインパスワードで更新します。\n",
    "The share will expire on %s." : "共有は %s で有効期限が切れます。",
    "Cheers!" : "それでは！",
    "Hey there,<br><br>The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"Basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"Old log-in password\" field and your current login-password.<br><br>" : "こんにちは、<br><br>管理者がサーバーサイド暗号化を有効にしました。<strong>%s</strong>というパスワードであなたのファイルが暗号化されました。<br><br>Web画面からログインして、個人設定画面の\"基本暗号化モジュール\"のセクションにいき、暗号化パスワードの更新をお願いします。\"旧ログインパスワード\"部分に上記パスワードを入力し、現在のログインパスワードで更新します。<br><br>",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "暗号化アプリは有効ですが、あなたの暗号化キーは初期化されていません。ログアウトした後に、再度ログインしてください",
    "Encrypt the home storage" : "メインストレージ暗号化",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "このオプションを有効にすると、外部ストレージ接続ストレージだけが暗号化されるのではなく、メインストレージのファイルすべてが暗号化されます。",
    "Enable recovery key" : "復旧キーを有効にする",
    "Disable recovery key" : "復旧キーを無効にする",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "復旧キーは、ファイルの暗号化に使う特別な暗号化キーです。ユーザーがパスワードを忘れてしまった場合には、リカバリキーを使ってユーザーのファイルを復元することができます。",
    "Recovery key password" : "復旧キーのパスワード",
    "Repeat recovery key password" : "復旧キーのパスワードをもう一度入力",
    "Change recovery key password:" : "復旧キーのパスワードを変更:",
    "Old recovery key password" : "古い復旧キーのパスワード",
    "New recovery key password" : "新しい復旧キーのパスワード",
    "Repeat new recovery key password" : "新しい復旧キーのパスワードをもう一度入力",
    "Change Password" : "パスワードを変更",
    "Basic encryption module" : "基本暗号化モジュール",
    "Your private key password no longer matches your log-in password." : "もはや秘密鍵はログインパスワードと一致しません。",
    "Set your old private key password to your current log-in password:" : "古い秘密鍵のパスワードを現在のログインパスワードに設定:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "古いパスワードを覚えていない場合、管理者に尋ねてファイルを回復することができます。",
    "Old log-in password" : "古いログインパスワード",
    "Current log-in password" : "現在のログインパスワード",
    "Update Private Key Password" : "秘密鍵のパスワードを更新",
    "Enable password recovery:" : "パスワードリカバリを有効に:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "このオプションを有効にすると、パスワードを紛失した場合も、暗号化されたファイルに再度アクセスすることができるようになります。",
    "Enabled" : "有効",
    "Disabled" : "無効"
},
"nplurals=1; plural=0;");
